---
layout: doc
weight: 1
title: Welcome
categories: getting-started
permalink: /getting-started/welcome
---

Intro.js is an open source vanilla Javascript / CSS library to add step-by-step introduction or hints.

#### Dependencies

Intro.js doesn't have any dependencies. All you need to do is adding the JS and CSS file, that's it.

#### Author

 - Afshin Mehrabani (afshin.meh at gmail.com)  
 - Benjamin J DeLong  

and many [contributors](https://github.com/usablica/intro.js/graphs/contributors).

#### License

##### Commercial license

If you want to use Intro.js for a commercial application, theme or plugin the commercial license is the appropriate license. With this option, your source code is kept proprietary. Purchase a commercial license at [introjs.com](http://introjs.com/#commercial)

##### Open-source license

GNU AGPLv3
